/***************************************************************************
                          kstlistenums.h  -  enums used by curve/vector lists
                             -------------------
    begin                : Jan 18, 2003
    copyright            : (C) 2003 by Barth Netterfield
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSTLISTENUMS_H
#define KSTLISTENUMS_H

enum RemoveStatus { SLAVE_USED, NOT_CURVE, CURVE_DELETED, VECTOR_DELETED, VECTOR_USED, NOT_VECTOR, PLUGIN_DELETED, NOT_PLUGIN, OBJECT_DELETED, NOT_OBJECT };


#endif
